@@ -11,7 +11,7 @@ Graph::ModularDecomposition - Modular decomposition of directed graphs
 =cut
 
 require Exporter;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Graph 0.20105;
 require Graph::Directed;
@@ -177,7 +177,7 @@ sub canonical_form {
     $g = Graph::ModularDecomposition->new; # same thing
     my $h = $g->new;
 
-Constructor.  The instance method style C<$object>->C<new> is an extension
+Constructor.  The instance method style C<< $object->new >> is an extension
 and was not present in L<Graph::Directed|Graph::Directed>.
 
 =cut
@@ -754,7 +754,7 @@ __END__
 
 =head1 AUTHOR
 
-Andras Salamon, E<lt>azs@cpan.netE<gt>
+Andras Salamon, E<lt>azs@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
